# Base AzQueueManager  Extension Template
teamplate for building extensions for AZ Queue Manager

## Getting Started
- Create a new repository from this template.
- Update the pyproject.toml file
  - add your requirements `project.dependencies`
